summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-02-17 13:30:33 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2012-02-18 23:32:49 -0600
commit0207529f275bf1524aa60f2ea58f522ed6c1e26c (patch)
tree49bc054b35eec30cf01f4345f2c5514d6d1f967b /png.h
parenta08f60352c3f6cb2caba75c1465bf447018aa3e2 (diff)
downloadlibpng-0207529f275bf1524aa60f2ea58f522ed6c1e26c.tar.gz
[libpng15] Imported from libpng-1.5.9rc01.tarv1.5.9rc01
Diffstat (limited to 'png.h')
-rw-r--r--png.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/png.h b/png.h
index 809efeffc..b0b0b3d1f 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.9beta01 - February 3, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.9beta01 - February 3, 2012: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -169,7 +169,8 @@
* 1.5.8beta01 15 10508 15.so.15.8[.0]
* 1.5.8rc01 15 10508 15.so.15.8[.0]
* 1.5.8 15 10508 15.so.15.8[.0]
- * 1.5.9beta01 15 10509 15.so.15.9[.0]
+ * 1.5.9beta01-02 15 10509 15.so.15.9[.0]
+ * 1.5.9rc01 15 10509 15.so.15.9[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -201,7 +202,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.9beta01, February 3, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -313,13 +314,13 @@
* Y2K compliance in libpng:
* =========================
*
- * February 3, 2012
+ * February 17, 2012
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.5.9beta01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -377,9 +378,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.9beta01"
+#define PNG_LIBPNG_VER_STRING "1.5.9rc01"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.9beta01 - February 3, 2012\n"
+ " libpng version 1.5.9rc01 - February 17, 2012\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -540,7 +541,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_9beta01;
+typedef char* png_libpng_version_1_5_9rc01;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.9beta01 - February 3, 2012
+ * libpng version 1.5.9rc01 - February 17, 2012
* Copyright (c) 1998-2012 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.9beta01 - February 3, 2012: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.9rc01 - February 17, 2012: Glenn
* See also "Contributing Authors", below.
*
@@ -201,7 +202,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.9beta01, February 3, 2012, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.9rc01, February 17, 2012, are
* Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -313,13 +314,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.9beta01 are Y2K compliant. It is my belief that
+ * upward through 1.5.9rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*